@@ -70,7 +70,7 @@ class DiegoOperator(PythonOperator):
         print(f"File sent to Diego to path {file_path}")
         print(f"Diego response {response.text}")
 
-        return response
+        return response.json()['replyId']
 
     def __upload_df_to_s3_temp(self, df: pd.DataFrame, path, part_number, pandas_kwargs=None):
         if pandas_kwargs is None:
@@ -118,18 +118,13 @@ class DiegoOperator(PythonOperator):
 
     def execute(self, context):
         df = super().execute(context)
-
-        temp_file_path = f"cortex-data-lakehouse-metastore-development/temp-files-diego/{self.task_id}/{self.cube_id}/{str(hash(datetime.utcnow().isoformat()))}"
-
         if isinstance(df, collections.Iterator):
-            for part_number, df_part in enumerate(df):
-                self.__execute_df(df=df_part, part_number=part_number, path=f"s3://{temp_file_path}")
+            for df_part in df:
+                execution_ids = self.__execute_df(df=df_part)
         else:
-            self.__execute_df(df=df, part_number=1, path=f"s3://{temp_file_path}")
-
-        response = self.send_file_path_to_diego(temp_file_path)
-
-        if not self.ignore_empty_dataframe and not response.json().get("replyId"):
+            execution_ids = self.__execute_df(df=df)
+        if not self.ignore_empty_dataframe:
             raise ValueError('There were no dataframes written to Diego. Please check if your dataframes are empty')
 
         context['task_instance'].xcom_push(key='platform_url', value=self.platform_url)
+        context['task_instance'].xcom_push(key='execution_ids', value=execution_ids)
