@@ -101,3 +101,14 @@ def drop_table_duplicates(db_name: str, table_name: str, unique_id_fields: list
     existing_table.alias(existing_table_alias).merge(df_last_sort.alias(inserting_table_alias), unique_condition). \
         whenMatchedDelete(match_condition). \
         execute()
+
+def set_comment_table(catalog, table, comment, spark=None):
+    if spark is None:
+        spark = get_spark_session(f'comment_table')
+    table_exists = check_table_exists(catalog, table)
+    if table_exists :
+        spark.sql(f""" COMMENT ON TABLE {catalog}.{table} IS '{comment}';""")
+        return True
+    else:
+        print(f"table not found, please check")
+        return False
